# plots for the stecf comments section

library(ggplot2)
load("RData.nea")
load("RData.med")
theme_set(theme_bw())
options(stringsAsFactors=FALSE)
v0 <- 2003:2015
v0[seq(2,12,2)] <- ""
sc <- scale_x_continuous(breaks=2003:2015, labels=as.character(v0))
th <- theme(axis.text  = element_text(angle=0, vjust=0.5, size=14), panel.grid.minor = element_blank(), legend.title  = element_text(size=18), legend.text  = element_text(size=14), axis.title.y  = element_text(size=18))

# fig221

df0 <- fInda
df0$stat <- fInda$N/(fInda$N+fIndb$N)
df0$Indicator <- "Overfished stocks"

df1 <- fInda
df1$stat <- fIndc$N/(fIndc$N+fIndd$N)
df1$Indicator <- "Outside Safe Bio Limits"

df2 <- fInda
df2$stat <- fIndf$N/(fIndf$N+fIndfb$N) 
df2$Indicator <- "Outside CFP requirements"

df0 <- rbind(df0, df1, df2)
df0 <- subset(df0, EcoRegion=='ALL')

png("fig221.png", 800, 400)
ggplot(df0, aes(x=Year, y=stat*100, colour=Indicator, shape=Indicator)) + 
	geom_line(size=1) + 
	geom_point(size=2) +
	ylab("Percentage of stocks") + 
	xlab("") + 
	ylim(c(0,100)) + 
	sc + 
	th + 
	theme(legend.position=c(0.15, 0.3)) +
	scale_color_manual(values=c("orange", "blue", "red"))
dev.off()	

# fig 222
df0 <- do.call("rbind", ifit.bs)
df0 <- data.frame(Year=2003:2015, stat=apply(df0, 2, quantile, 0.50, na.rm=TRUE), Indicator="NEA: EU coastal waters")

df1 <- do.call("rbind", ifitout.bs)
df1 <- data.frame(Year=2003:2015, stat=apply(df1, 2, quantile, 0.50, na.rm=TRUE), Indicator="NEA: outside EU coastal waters")

df2 <- do.call("rbind", mfit.bs)
df2 <- data.frame(Year=2003:2014, stat=apply(df2, 2, quantile, 0.50, na.rm=TRUE), Indicator="MED&BS: EU coastal waters")

df0 <- rbind(df0, df1, df2)

png("fig222.png", 800, 400)
ggplot(df0, aes(x=Year, y=stat, colour=Indicator, shape=Indicator)) + 
	geom_hline(yintercept = 1, linetype=2) +
	geom_line(size=1) + 
	geom_point(size=2) +
	xlab("") + 
	ylab(expression(F/F[MSY])) + 
	ylim(c(0,3)) + 
	sc + 
	th + 
	theme(legend.position=c(0.2, 0.2)) + 
	scale_color_manual(values=c("black", "red", "green"))
dev.off()	

# fig 223
ifitm <- do.call("rbind", ifitb.bs)
df0 <- exp(log(ifitm)-mean(log(ifitm[,1]), na.rm=TRUE))
df0 <- data.frame(Year=2003:2015, stat=apply(df0, 2, quantile, 0.50, na.rm=TRUE), Indicator="Biomass in NEA")

mfitm <- do.call("rbind", mfitb.bs)
df1 <- exp(log(mfitm)-mean(log(mfitm[,1]), na.rm=TRUE))
df1 <- data.frame(Year=2003:2014, stat=apply(df1, 2, quantile, 0.50, na.rm=TRUE), Indicator="Biomass in MED&BS")

df0 <- rbind(df0, df1)

png("fig223.png", 800, 400)
ggplot(df0, aes(x=Year, y=stat, colour=Indicator, shape=Indicator)) + 
	geom_hline(yintercept = 1, linetype=2) +
	geom_line(size=1) + 
	geom_point(size=2) +
	xlab("") + 
	ylab(expression(B/B[2003])) + 
	ylim(c(0,2)) + 
	sc + 
	th + 
	theme(legend.position=c(0.2, 0.2)) + 
	scale_color_manual(values=c("black", "blue"))
dev.off()	



